summaryrefslogtreecommitdiffstats
path: root/kdirstat
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:00:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:00:07 -0600
commitebffb6c8232a7667588f3d879942f93d5d990913 (patch)
tree0b1016fea858abebdbaf1a04de3630bf34acb3e9 /kdirstat
parentf3263ec262bd31545a27af4e3b8c537654e9fa40 (diff)
downloadkdirstat-ebffb6c8232a7667588f3d879942f93d5d990913.tar.gz
kdirstat-ebffb6c8232a7667588f3d879942f93d5d990913.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kdirstat')
-rw-r--r--kdirstat/kcleanup.cpp12
-rw-r--r--kdirstat/kcleanup.h14
-rw-r--r--kdirstat/kcleanupcollection.cpp12
-rw-r--r--kdirstat/kcleanupcollection.h8
-rw-r--r--kdirstat/kdirstatapp.cpp36
-rw-r--r--kdirstat/kdirstatapp.h58
-rw-r--r--kdirstat/kdirtreeview.h2
-rw-r--r--kdirstat/kstdcleanup.cpp14
-rw-r--r--kdirstat/kstdcleanup.h16
9 files changed, 86 insertions, 86 deletions
diff --git a/kdirstat/kcleanup.cpp b/kdirstat/kcleanup.cpp
index 3cd6f7e..831b628 100644
--- a/kdirstat/kcleanup.cpp
+++ b/kdirstat/kcleanup.cpp
@@ -31,9 +31,9 @@ using namespace KDirStat;
KCleanup::KCleanup( TQString id,
TQString command,
TQString title,
- KActionCollection * parent )
+ TDEActionCollection * parent )
- : KAction( title,
+ : TDEAction( title,
0, // accel
parent,
id )
@@ -52,12 +52,12 @@ KCleanup::KCleanup( TQString id,
_askForConfirmation = false;
_refreshPolicy = noRefresh;
- KAction::setEnabled( false );
+ TDEAction::setEnabled( false );
}
KCleanup::KCleanup( const KCleanup &src )
- : KAction()
+ : TDEAction()
{
copy( src );
}
@@ -94,7 +94,7 @@ void
KCleanup::setTitle( const TQString &title )
{
_title = title;
- KAction::setText( _title );
+ TDEAction::setText( _title );
}
@@ -147,7 +147,7 @@ KCleanup::selectionChanged( KFileInfo *selection )
}
}
- KAction::setEnabled( enabled );
+ TDEAction::setEnabled( enabled );
}
diff --git a/kdirstat/kcleanupcollection.h b/kdirstat/kcleanupcollection.h
index 5c9529b..c1c9815 100644
--- a/kdirstat/kcleanupcollection.h
+++ b/kdirstat/kcleanupcollection.h
@@ -20,7 +20,7 @@
#include "kcleanup.h"
// Forward declarations
-class KActionCollection;
+class TDEActionCollection;
namespace KDirStat
@@ -53,14 +53,14 @@ namespace KDirStat
/**
* Constructor.
*
- * Most applications will want to pass KMainWindow::actionCollection()
+ * Most applications will want to pass TDEMainWindow::actionCollection()
* for 'actionCollection' so the menus and toolbars can be created
* using the XML UI description ('kdirstatui.rc' for KDirStat).
*
* All @ref KCleanup actions ever added to this collection will get
* this as their parent.
**/
- KCleanupCollection( KActionCollection * actionCollection = 0 );
+ KCleanupCollection( TDEActionCollection * actionCollection = 0 );
/**
* Copy Constructor.
@@ -212,7 +212,7 @@ namespace KDirStat
// Data members
- KActionCollection * _actionCollection;
+ TDEActionCollection * _actionCollection;
int _nextUserCleanupNo;
KCleanupList _cleanupList;
KCleanupDict _cleanupDict;
diff --git a/kdirstat/kdirstatapp.cpp b/kdirstat/kdirstatapp.cpp
index 33c4d73..c7e53f3 100644
--- a/kdirstat/kdirstatapp.cpp
+++ b/kdirstat/kdirstatapp.cpp
@@ -55,7 +55,7 @@ using namespace KDirStat;
KDirStatApp::KDirStatApp( TQWidget* , const char* name )
- : KMainWindow( 0, name )
+ : TDEMainWindow( 0, name )
{
// Simple inits
@@ -143,26 +143,26 @@ KDirStatApp::initActions()
{
_fileAskOpenDir = KStdAction::open ( TQT_TQOBJECT(this), TQT_SLOT( fileAskOpenDir() ), actionCollection() );
- _fileAskOpenUrl = new KAction( i18n( "Open &URL..." ), "konqueror", 0,
+ _fileAskOpenUrl = new TDEAction( i18n( "Open &URL..." ), "konqueror", 0,
TQT_TQOBJECT(this), TQT_SLOT( fileAskOpenUrl() ),
actionCollection(), "file_open_url" );
_fileOpenRecent = KStdAction::openRecent ( TQT_TQOBJECT(this), TQT_SLOT( fileOpenRecent( const KURL& ) ), actionCollection() );
_fileCloseDir = KStdAction::close ( TQT_TQOBJECT(this), TQT_SLOT( fileCloseDir() ), actionCollection() );
- _fileRefreshAll = new KAction( i18n( "Refresh &All" ), "reload", 0,
+ _fileRefreshAll = new TDEAction( i18n( "Refresh &All" ), "reload", 0,
TQT_TQOBJECT(this), TQT_SLOT( refreshAll() ),
actionCollection(), "file_refresh_all" );
- _fileRefreshSelected = new KAction( i18n( "Refresh &Selected" ), 0,
+ _fileRefreshSelected = new TDEAction( i18n( "Refresh &Selected" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( refreshSelected() ),
actionCollection(), "file_refresh_selected" );
- _fileContinueReadingAtMountPoint = new KAction( i18n( "Continue Reading at &Mount Point" ), "hdd_mount", 0,
+ _fileContinueReadingAtMountPoint = new TDEAction( i18n( "Continue Reading at &Mount Point" ), "hdd_mount", 0,
TQT_TQOBJECT(this), TQT_SLOT( refreshSelected() ), actionCollection(),
"file_continue_reading_at_mount_point" );
- _fileStopReading = new KAction( i18n( "Stop Rea&ding" ), "stop", 0,
+ _fileStopReading = new TDEAction( i18n( "Stop Rea&ding" ), "stop", 0,
TQT_TQOBJECT(this), TQT_SLOT( stopReading() ), actionCollection(),
"file_stop_reading" );
@@ -171,41 +171,41 @@ KDirStatApp::initActions()
_showToolBar = KStdAction::showToolbar ( TQT_TQOBJECT(this), TQT_SLOT( toggleToolBar() ), actionCollection() );
_showStatusBar = KStdAction::showStatusbar ( TQT_TQOBJECT(this), TQT_SLOT( toggleStatusBar() ), actionCollection() );
- _cleanupOpenWith = new KAction( i18n( "Open With" ), 0,
+ _cleanupOpenWith = new TDEAction( i18n( "Open With" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( cleanupOpenWith() ),
actionCollection(), "cleanup_open_with" );
- _treemapZoomIn = new KAction( i18n( "Zoom in" ), "viewmag+", Key_Plus,
+ _treemapZoomIn = new TDEAction( i18n( "Zoom in" ), "viewmag+", Key_Plus,
TQT_TQOBJECT(this), TQT_SLOT( treemapZoomIn() ),
actionCollection(), "treemap_zoom_in" );
- _treemapZoomOut = new KAction( i18n( "Zoom out" ), "viewmag-", Key_Minus,
+ _treemapZoomOut = new TDEAction( i18n( "Zoom out" ), "viewmag-", Key_Minus,
TQT_TQOBJECT(this), TQT_SLOT( treemapZoomOut() ),
actionCollection(), "treemap_zoom_out" );
- _treemapSelectParent= new KAction( i18n( "Select Parent" ), "up", Key_Asterisk,
+ _treemapSelectParent= new TDEAction( i18n( "Select Parent" ), "up", Key_Asterisk,
TQT_TQOBJECT(this), TQT_SLOT( treemapSelectParent() ),
actionCollection(), "treemap_select_parent" );
- _treemapRebuild = new KAction( i18n( "Rebuild Treemap" ), 0,
+ _treemapRebuild = new TDEAction( i18n( "Rebuild Treemap" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( treemapRebuild() ),
actionCollection(), "treemap_rebuild" );
- _showTreemapView = new KToggleAction( i18n( "Show Treemap" ), Key_F9,
+ _showTreemapView = new TDEToggleAction( i18n( "Show Treemap" ), Key_F9,
TQT_TQOBJECT(this), TQT_SLOT( toggleTreemapView() ),
actionCollection(), "options_show_treemap" );
- new KAction( i18n( "Help about Treemaps" ), "help", 0,
+ new TDEAction( i18n( "Help about Treemaps" ), "help", 0,
TQT_TQOBJECT(this), TQT_SLOT( treemapHelp() ),
actionCollection(), "treemap_help" );
- KAction * pref = KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT( preferences() ), actionCollection() );
+ TDEAction * pref = KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT( preferences() ), actionCollection() );
- _reportMailToOwner = new KAction( i18n( "Send &Mail to Owner" ), "mail_generic", 0,
+ _reportMailToOwner = new TDEAction( i18n( "Send &Mail to Owner" ), "mail_generic", 0,
TQT_TQOBJECT(_treeView), TQT_SLOT( sendMailToOwner() ),
actionCollection(), "report_mail_to_owner" );
- _helpSendFeedbackMail = new KAction( i18n( "Send &Feedback Mail..." ), 0,
+ _helpSendFeedbackMail = new TDEAction( i18n( "Send &Feedback Mail..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( sendFeedbackMail() ),
actionCollection(), "help_send_feedback_mail" );
@@ -362,8 +362,8 @@ void KDirStatApp::readMainWinConfig()
// Position settings of the various bars
- KToolBar::BarPosition toolBarPos;
- toolBarPos = ( KToolBar::BarPosition ) config->readNumEntry( "ToolBarPos", KToolBar::Top );
+ TDEToolBar::BarPosition toolBarPos;
+ toolBarPos = ( TDEToolBar::BarPosition ) config->readNumEntry( "ToolBarPos", TDEToolBar::Top );
toolBar( "mainToolBar" )->setBarPos( toolBarPos );
_treemapViewHeight = config->readNumEntry( "TreemapViewHeight", 250 );
diff --git a/kdirstat/kdirtreeview.h b/kdirstat/kdirtreeview.h
index 1a3ff94..8e4ce25 100644
--- a/kdirstat/kdirtreeview.h
+++ b/kdirstat/kdirtreeview.h
@@ -51,7 +51,7 @@ namespace KDirStat
#if USE_KLISTVIEW
-# define KDirTreeViewParentClass KListView
+# define KDirTreeViewParentClass TDEListView
#else
# define KDirTreeViewParentClass TQListView
#endif
diff --git a/kdirstat/kstdcleanup.cpp b/kdirstat/kstdcleanup.cpp
index b153e34..df21802 100644
--- a/kdirstat/kstdcleanup.cpp
+++ b/kdirstat/kstdcleanup.cpp
@@ -16,7 +16,7 @@ using namespace KDirStat;
KCleanup *
-KStdCleanup::openInKonqueror( KActionCollection *parent )
+KStdCleanup::openInKonqueror( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_open_in_konqueror",
"kfmclient openURL %p",
@@ -36,7 +36,7 @@ KStdCleanup::openInKonqueror( KActionCollection *parent )
KCleanup *
-KStdCleanup::openInTerminal( KActionCollection *parent )
+KStdCleanup::openInTerminal( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_open_in_terminal",
"konsole",
@@ -55,7 +55,7 @@ KStdCleanup::openInTerminal( KActionCollection *parent )
KCleanup *
-KStdCleanup::compressSubtree( KActionCollection *parent )
+KStdCleanup::compressSubtree( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_compress_subtree",
"cd ..; tar cjvf %n.tar.bz2 %n && rm -rf %n",
@@ -73,7 +73,7 @@ KStdCleanup::compressSubtree( KActionCollection *parent )
KCleanup *
-KStdCleanup::makeClean( KActionCollection *parent )
+KStdCleanup::makeClean( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_make_clean",
"make clean",
@@ -90,7 +90,7 @@ KStdCleanup::makeClean( KActionCollection *parent )
KCleanup *
-KStdCleanup::deleteTrash( KActionCollection *parent )
+KStdCleanup::deleteTrash( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_delete_trash",
"rm -f *.o *~ *.bak *.auto core",
@@ -108,7 +108,7 @@ KStdCleanup::deleteTrash( KActionCollection *parent )
KCleanup *
-KStdCleanup::moveToTrashBin( KActionCollection *parent )
+KStdCleanup::moveToTrashBin( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_move_to_trash_bin",
"kfmclient move %p %t",
@@ -127,7 +127,7 @@ KStdCleanup::moveToTrashBin( KActionCollection *parent )
KCleanup *
-KStdCleanup::hardDelete( KActionCollection *parent )
+KStdCleanup::hardDelete( TDEActionCollection *parent )
{
KCleanup *cleanup = new KCleanup( "cleanup_hard_delete",
"rm -rf %p",
diff --git a/kdirstat/kstdcleanup.h b/kdirstat/kstdcleanup.h
index 110cd2b..c5114d4 100644
--- a/kdirstat/kstdcleanup.h
+++ b/kdirstat/kstdcleanup.h
@@ -17,7 +17,7 @@
#endif
// Forward declarations
-class KActionCollection;
+class TDEActionCollection;
class KDirStat::KCleanup;
@@ -40,13 +40,13 @@ namespace KDirStat
class KStdCleanup
{
public:
- static KCleanup *openInKonqueror ( KActionCollection *parent = 0 );
- static KCleanup *openInTerminal ( KActionCollection *parent = 0 );
- static KCleanup *compressSubtree ( KActionCollection *parent = 0 );
- static KCleanup *makeClean ( KActionCollection *parent = 0 );
- static KCleanup *deleteTrash ( KActionCollection *parent = 0 );
- static KCleanup *moveToTrashBin ( KActionCollection *parent = 0 );
- static KCleanup *hardDelete ( KActionCollection *parent = 0 );
+ static KCleanup *openInKonqueror ( TDEActionCollection *parent = 0 );
+ static KCleanup *openInTerminal ( TDEActionCollection *parent = 0 );
+ static KCleanup *compressSubtree ( TDEActionCollection *parent = 0 );
+ static KCleanup *makeClean ( TDEActionCollection *parent = 0 );
+ static KCleanup *deleteTrash ( TDEActionCollection *parent = 0 );
+ static KCleanup *moveToTrashBin ( TDEActionCollection *parent = 0 );
+ static KCleanup *hardDelete ( TDEActionCollection *parent = 0 );
private:
/**
diff --git a/kdirstat/kcleanup.h b/kdirstat/kcleanup.h
index e17c793..54e7930 100644
--- a/kdirstat/kcleanup.h
+++ b/kdirstat/kcleanup.h
@@ -33,7 +33,7 @@ namespace KDirStat
* @short KDirStat cleanup action
**/
- class KCleanup: public KAction
+ class KCleanup: public TDEAction
{
Q_OBJECT
@@ -49,21 +49,21 @@ namespace KDirStat
* and config files, 'title' is the human readable menu title.
* 'command' is the shell command to execute.
*
- * Most applications will want to pass KMainWindow::actionCollection()
+ * Most applications will want to pass TDEMainWindow::actionCollection()
* for 'parent' so the menus and toolbars can be created using the XML
* UI description ('kdirstatui.rc' for KDirStat).
**/
KCleanup( TQString id = "",
TQString command = "",
TQString title = "",
- KActionCollection * parent = 0 );
+ TDEActionCollection * parent = 0 );
/**
* Copy Constructor.
*
* Notice that this is a not quite complete copy constructor: Since
* there is no KAction copy constructor, the inherited KAction members
* will be constructed with the KAction default constructor. Thus, an
* object created with this copy constructor can rely only on its
* KCleanup members. This is intended for save/restore operations only,
* not for general use. In particular, DO NOT connect an object thus
@@ -74,7 +74,7 @@ namespace KDirStat
/**
* Assignment operator.
*
* This will not modify the KAction members, just the KCleanup
* members. Just like the copy constructor, this is intended for
* save/restore operations, not for general use.
**/
@@ -261,7 +261,7 @@ namespace KDirStat
protected slots:
/**
* Inherited from @ref KAction : Perform the action.
* In this case, execute the cleanup with the current selection.
**/
virtual void slotActivated() { executeWithSelection(); }
@@ -49,21 +49,21 @@ namespace KDirStat
*
* Notice that this is a not quite complete copy constructor: Since
- * there is no KAction copy constructor, the inherited KAction members
- * will be constructed with the KAction default constructor. Thus, an
+ * there is no TDEAction copy constructor, the inherited TDEAction members
+ * will be constructed with the TDEAction default constructor. Thus, an
* object created with this copy constructor can rely only on its
* KCleanup members. This is intended for save/restore operations only,
@@ -74,7 +74,7 @@ namespace KDirStat
* Assignment operator.
*
- * This will not modify the KAction members, just the KCleanup
+ * This will not modify the TDEAction members, just the KCleanup
* members. Just like the copy constructor, this is intended for
* save/restore operations, not for general use.
@@ -261,7 +261,7 @@ namespace KDirStat
protected slots:
/**
- * Inherited from @ref KAction : Perform the action.
+ * Inherited from @ref TDEAction : Perform the action.
* In this case, execute the cleanup with the current selection.
**/
diff --git a/kdirstat/kcleanupcollection.cpp b/kdirstat/kcleanupcollection.cpp
index 39f0b1c..146dfe6 100644
--- a/kdirstat/kcleanupcollection.cpp
+++ b/kdirstat/kcleanupcollection.cpp
@@ -17,7 +17,7 @@
using namespace KDirStat;
-KCleanupCollection::KCleanupCollection( KActionCollection * actionCollection )
+KCleanupCollection::KCleanupCollection( TDEActionCollection * actionCollection )
: TQObject()
, _actionCollection( actionCollection )
{
@@ -41,7 +41,7 @@ KCleanupCollection::KCleanupCollection( const KCleanupCollection &src )
deepCopy( src );
// Keep consistent with the KCleanup copy constructor: It explicitly uses a
// zero KActionCollecton to make sure no duplicates of cleanups get into
// the action collection.
_actionCollection = 0;
}
@@ -79,7 +79,7 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* The background of this seemingly awkward solution are (again) the
* limitations of the KCleanup copy constructor: It doesn't make a
* truly identical copy of the entire KCleanup object. Rather, it
* copies only the KCleanup members and leaves most of the KAction
* members (the parent class) untouched.
*
* The behaviour implemented here comes handy in the most common
@@ -93,20 +93,20 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
*
* 'tmpCollection' here is an incomplete copy of 'origCollection' -
* which represents what the user really can see in the menus, i.e. all
* the KAction stuff in there really needs to work.
*
* During changing preferences in the 'settings' dialog, the user only
* changes 'tmpCollection' - if he chooses to abandon his changes
* (e.g., he clicks on the 'cancel' button), no harm is done -
* 'tmpCollection' is simply not copied back to
* 'origCollection'. Anyway, since 'tmpCollection' is merely a
* container for the true KCleanup members, the KAction members don't
* matter here: There is no representation of 'tmpCollection' in any
* menu or tool bar.
*
* As soon as the user clicks on 'apply' or 'ok' in the 'settings'
* dialog, however, 'tmpCollection' is copied back to 'origCollection'
* - that is, its KCleanup members. Most of the KAction members (other
* than 'text()' which is explicitly copied back) remain untouched,
* thus maintaining consistency with the user interface is guaranteed.
**/
@@ -41,7 +41,7 @@ KCleanupCollection::KCleanupCollection( const KCleanupCollection &src )
deepCopy( src );
// Keep consistent with the KCleanup copy constructor: It explicitly uses a
- // zero KActionCollecton to make sure no duplicates of cleanups get into
+ // zero TDEActionCollecton to make sure no duplicates of cleanups get into
// the action collection.
_actionCollection = 0;
@@ -79,7 +79,7 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* limitations of the KCleanup copy constructor: It doesn't make a
* truly identical copy of the entire KCleanup object. Rather, it
- * copies only the KCleanup members and leaves most of the KAction
+ * copies only the KCleanup members and leaves most of the TDEAction
* members (the parent class) untouched.
*
@@ -93,20 +93,20 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* 'tmpCollection' here is an incomplete copy of 'origCollection' -
* which represents what the user really can see in the menus, i.e. all
- * the KAction stuff in there really needs to work.
+ * the TDEAction stuff in there really needs to work.
*
* During changing preferences in the 'settings' dialog, the user only
@@ -93,20 +93,20 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* 'tmpCollection' is simply not copied back to
* 'origCollection'. Anyway, since 'tmpCollection' is merely a
- * container for the true KCleanup members, the KAction members don't
+ * container for the true KCleanup members, the TDEAction members don't
* matter here: There is no representation of 'tmpCollection' in any
* menu or tool bar.
@@ -93,20 +93,20 @@ KCleanupCollection::operator= ( const KCleanupCollection &src )
* As soon as the user clicks on 'apply' or 'ok' in the 'settings'
* dialog, however, 'tmpCollection' is copied back to 'origCollection'
- * - that is, its KCleanup members. Most of the KAction members (other
+ * - that is, its KCleanup members. Most of the TDEAction members (other
* than 'text()' which is explicitly copied back) remain untouched,
* thus maintaining consistency with the user interface is guaranteed.
diff --git a/kdirstat/kdirstatapp.h b/kdirstat/kdirstatapp.h
index d23e5f9..e2a0108 100644
--- a/kdirstat/kdirstatapp.h
+++ b/kdirstat/kdirstatapp.h
@@ -27,15 +27,15 @@
class TQPopupMenu;
class TQSplitter;
-class KAction;
+class TDEAction;
class KActivityTracker;
class KFeedbackDialog;
class KFeedbackDialog;
class KFeedbackQuestion;
class KPacMan;
class KPacMan;
-class KRecentFilesAction;
-class KToggleAction;
+class TDERecentFilesAction;
+class TDEToggleAction;
namespace KDirStat
{
@@ -56,10 +56,10 @@ using namespace KDirStat;
* and reads the config file as well as providing a menubar, toolbar and
* statusbar. An instance of KDirStatView creates your center view, which is
* connected to the window's Doc object. KDirStatApp reimplements the methods
* that KMainWindow provides for main window handling and supports full
* session management as well as using KActions.
*
- * @see KMainWindow
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig
*
@@ -68,7 +68,7 @@ using namespace KDirStat;
*
* @version KDevelop version 1.2 code generation
**/
-class KDirStatApp : public KMainWindow
+class KDirStatApp : public TDEMainWindow
{
Q_OBJECT
@@ -304,7 +304,7 @@ signals:
protected:
/**
- * Initialize the KActions of the application.
+ * Initialize the TDEActions of the application.
**/
void initActions();
@@ -388,27 +388,27 @@ protected:
// Actions
- KAction * _fileAskOpenDir;
- KAction * _fileAskOpenUrl;
- KRecentFilesAction * _fileOpenRecent;
- KAction * _fileCloseDir;
- KAction * _fileRefreshAll;
- KAction * _fileRefreshSelected;
- KAction * _fileContinueReadingAtMountPoint;
- KAction * _fileStopReading;
- KAction * _fileQuit;
- KAction * _editCopy;
- KAction * _cleanupOpenWith;
- KAction * _treemapZoomIn;
- KAction * _treemapZoomOut;
- KAction * _treemapSelectParent;
- KAction * _treemapRebuild;
-
- KAction * _reportMailToOwner;
- KAction * _helpSendFeedbackMail;
- KToggleAction * _showToolBar;
- KToggleAction * _showStatusBar;
- KToggleAction * _showTreemapView;
+ TDEAction * _fileAskOpenDir;
+ TDEAction * _fileAskOpenUrl;
+ TDERecentFilesAction * _fileOpenRecent;
+ TDEAction * _fileCloseDir;
+ TDEAction * _fileRefreshAll;
+ TDEAction * _fileRefreshSelected;
+ TDEAction * _fileContinueReadingAtMountPoint;
+ TDEAction * _fileStopReading;
+ TDEAction * _fileQuit;
+ TDEAction * _editCopy;
+ TDEAction * _cleanupOpenWith;
+ TDEAction * _treemapZoomIn;
+ TDEAction * _treemapZoomOut;
+ TDEAction * _treemapSelectParent;
+ TDEAction * _treemapRebuild;
+
+ TDEAction * _reportMailToOwner;
+ TDEAction * _helpSendFeedbackMail;
+ TDEToggleAction * _showToolBar;
+ TDEToggleAction * _showStatusBar;
+ TDEToggleAction * _showTreemapView;
KCleanupCollection * _cleanupCollection;
@@ -56,10 +56,10 @@ using namespace KDirStat;
* statusbar. An instance of KDirStatView creates your center view, which is
* connected to the window's Doc object. KDirStatApp reimplements the methods
- * that KMainWindow provides for main window handling and supports full
- * session management as well as using KActions.
+ * that TDEMainWindow provides for main window handling and supports full
+ * session management as well as using TDEActions.
*